#define MFBFILLPOLY1RECT xf1bppFillPolyInvert
#define OPEQ ^=
#define EQWHOLEWORD ^=~0
#include "mfbmap.h"
#include "../../../mfb/mfbply1rct.c"
